#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const fs = require("fs");
const keytar_1 = require("keytar");
const path_1 = require("path");
const util_1 = require("util");
const argv_1 = require("./argv");
const list_1 = require("./list");
const state_1 = require("./state");
const transfer_1 = require("./transfer");
const readFile = util_1.promisify(fs.readFile);
const fatal = (errorText) => {
    console.error(chalk_1.default.bold.red(errorText));
    process.exit(1);
};
const assert = (condition, errorText) => {
    if (!condition) {
        fatal(errorText);
    }
};
async function getCookieFromRobloxStudio() {
    if (!["darwin", "win32"].includes(process.platform)) {
        return;
    }
    if (process.platform === "darwin") {
        try {
            const homePath = require("os").homedir();
            const binaryCookieData = await readFile(path_1.join(homePath, "Library/HTTPStorages/com.Roblox.RobloxStudio.binarycookies"), { encoding: "utf-8" });
            const matchGroups = binaryCookieData.match(/_\|WARNING:-DO-NOT-SHARE-THIS\.--Sharing-this-will-allow-someone-to-log-in-as-you-and-to-steal-your-ROBUX-and-items\.\|_[A-F\d]+/);
            if (!matchGroups || !matchGroups.length) {
                return;
            }
            return matchGroups[0];
        }
        catch (_a) {
            return;
        }
    }
    const cookie = await keytar_1.findPassword("https://www.roblox.com:RobloxStudioAuth.ROBLOSECURITY");
    if (!cookie) {
        return;
    }
    return cookie;
}
async function main() {
    assert((argv_1.default.group != null && !argv_1.default.user) || (argv_1.default.group == null && argv_1.default.user), "Please only specify one of: --user, --group");
    if (argv_1.default.inFile && !fs.existsSync(argv_1.default.inFile)) {
        fatal(`Specified input file ${argv_1.default.inFile} does not exist.`);
    }
    let cookie = await getCookieFromRobloxStudio();
    if (process.env.ROBLOSECURITY)
        cookie = process.env.ROBLOSECURITY;
    if (argv_1.default.cookie)
        cookie = argv_1.default.cookie;
    if (!cookie)
        fatal("Either set the ROBLOSECURITY environment variable or provide the --cookie option.");
    const state = await state_1.default(cookie);
    const inStream = argv_1.default.inFile
        ? fs.createReadStream(argv_1.default.inFile)
        : process.stdin;
    const outStream = argv_1.default.outFile
        ? fs.createWriteStream(argv_1.default.outFile)
        : process.stdout;
    if (argv_1.default.list) {
        await (argv_1.default.group
            ? list_1.getGroupList(outStream, state, argv_1.default.group)
            : list_1.getUserList(outStream, state));
        if (argv_1.default.outFile) {
            console.log(chalk_1.default.green(`Pulled animations, wrote to: ${argv_1.default.outFile}`));
        }
    }
    else {
        try {
            transfer_1.default(inStream, outStream, state, argv_1.default.concurrent, argv_1.default.group);
        }
        catch (e) {
            fatal(e.toString());
        }
    }
}
main().catch((e) => fatal(e.message + e.stack));
//# sourceMappingURL=index.js.map